@@ -219,7 +219,11 @@ class VasprunContext(object):
         for el in element:
             if el.tag == "v":
                 name = el.attrib.get("name", None)
-                meta = m_env.resolve_definition('x_vasp_incar_' + name, Quantity)
+                meta = None
+                try:
+                    meta = m_env.resolve_definition('x_vasp_incar_' + name, Quantity)
+                except KeyError:
+                    pass
                 if not meta:
                     self.logger.warn(
                         "Unknown INCAR parameter (not registered in the meta data): %s %s %r" % (
@@ -229,7 +233,11 @@ class VasprunContext(object):
                 setattr(section_method, meta.get('name'), vector_val)
             elif el.tag == "i":
                 name = el.attrib.get("name", None)
-                meta = m_env.resolve_definition('x_vasp_incar_' + name, Quantity)
+                meta = None
+                try:
+                    meta = m_env.resolve_definition('x_vasp_incar_' + name, Quantity)
+                except KeyError:
+                    pass
                 val_type = el.attrib.get("type")
                 if not meta:
                     self.logger.warn(
@@ -993,7 +1001,7 @@ class XmlParser(object):
                 else:
                     raise Exception("Unexpected event %s" % event)
         except ParseError as e:
-            self.super_context.logger.warn("Could not complete parsing: %s" % e, exc_info=e)
+            self.super_context.logger.error("Could not complete parsing: %s" % e, exc_info=e)
         except Exception as e:
             import traceback
             traceback.print_exc()
